Browser/WASM bindings for the Group Protocol Stack.
Exported JS classes: [MlsContext], [GroupNode], [GtpClient].
The async init function is generated automatically by wasm-pack.
Browser/WASM bindings for the Group Protocol Stack.
Exported JS classes: [MlsContext], [GroupNode], [GtpClient].
The async init function is generated automatically by wasm-pack.